@@ -1,30 +1,35 @@
 """Provides the O&M Enviroment class; a subclass of simpy.Environment."""
 
 
-import logging  # type: ignore
-import math  # type: ignore
 import os  # type: ignore
-from datetime import datetime, timedelta  # type: ignore
-from pathlib import Path  # type: ignore
-from typing import Optional, Tuple, Union  # type: ignore
-
+import math  # type: ignore
 import numpy as np  # type: ignore
-import pandas as pd  # type: ignore
 import simpy  # type: ignore
+import pandas as pd  # type: ignore
+import logging  # type: ignore
+from typing import Tuple, Union, Optional  # type: ignore
+from pathlib import Path  # type: ignore
+from datetime import datetime, timedelta  # type: ignore
 from simpy.events import Event  # type: ignore
+from pandas.core.indexes.datetimes import DatetimeIndex
 
-import wombat
+import wombat  # pylint: disable=W0611
 from wombat.utilities import (
-    format_events_log_message,
-    hours_until_future_hour,
     setup_logger,
+    hours_until_future_hour,
+    format_events_log_message,
 )
 
 
 class WombatEnvironment(simpy.Environment):
+    """The primary mechanism for powering an O&M simulation. This object has insight into
+    all other simulation objects, and controls the timing, date/time stamps, and weather
+    conditions.
+    """
+
     def __init__(
         self,
-        data_dir: str,
+        data_dir: Union[Path, str],
         weather_file: str,
         workday_start: int,
         workday_end: int,
@@ -32,7 +37,7 @@ class WombatEnvironment(simpy.Environment):
         start_year: Optional[int] = None,
         end_year: Optional[int] = None,
     ) -> None:
-        """wombat.Environment initialization.
+        """Initialization.
 
         Parameters
         ----------
@@ -41,36 +46,36 @@ class WombatEnvironment(simpy.Environment):
         data_dir : str
             Directory where the inputs are stored and where to save outputs.
         weather_file : str
-            Name of the weather file. Should be contained within `data_dir`/weather/.
+            Name of the weather file. Should be contained within ``data_dir``/weather/.
         workday_start : int
             Starting time for the repair crew, in 24 hour local time. This can be
-            overridden by an `ServiceEquipmentData` object that operates outside of the "typical"
+            overridden by an ``ServiceEquipmentData`` object that operates outside of the "typical"
             working hours.
         workday_end : int
             Ending time for the repair crew, in 24 hour local time. This can be
-            overridden by an `ServiceEquipmentData` object that operates outside of the "typical"
+            overridden by an ``ServiceEquipmentData`` object that operates outside of the "typical"
             working hours.
         simulation_name : Optional[str], optional
-            Name of the simulation; will be used for naming the log file, by default `None`.
-            If `None`, then the current time will be used. Will always save to
-            `data_dir`/outputs/logs/`simulation_name`.log.
+            Name of the simulation; will be used for naming the log file, by default ``None``.
+            If ``None``, then the current time will be used. Will always save to
+            ``data_dir``/outputs/logs/``simulation_name``.log.
             ... note: spaces (" ") will be replaced with underscores ("_"), for example:
             "my example analysis" becomes "my_example_analysis".
         start_year : Optional[int], optional
-            Custom starting year for the weather profile, by default None. If `None` or
+            Custom starting year for the weather profile, by default None. If ``None`` or
             less than the first year of the weather profile, this will be ignored.
         end_year : Optional[int], optional
-            Custom ending year for the weather profile, by default None. If `None` or
+            Custom ending year for the weather profile, by default None. If ``None`` or
             greater than the last year of the weather profile, this will be ignored.
 
         Raises
         ------
         FileNotFoundError
-            Raised if `data_dir` cannot be found.
+            Raised if ``data_dir`` cannot be found.
         """
         super().__init__()
-        self.data_dir = Path(data_dir)
-        if not os.path.isdir(self.data_dir):
+        self.data_dir = Path(data_dir).resolve()
+        if not self.data_dir.is_dir():
             raise FileNotFoundError(f"{self.data_dir} does not exist")
 
         self.workday_start = workday_start
@@ -93,15 +98,15 @@ class WombatEnvironment(simpy.Environment):
         self._logging_setup()
 
     def run(self, until: Optional[Union[int, float, Event]] = None):
-        """Extends the `simpy.Environment.run` method to change the default behavior if
-        no argument is passed to `until`, which will now run a simulation until the end
+        """Extends the ``simpy.Environment.run`` method to change the default behavior if
+        no argument is passed to ``until``, which will now run a simulation until the end
         of the weather profile is reached.
 
         Parameters
         ----------
         until : Optional[Union[int, float, Event]], optional
             When to stop the simulation, by default None. See documentation on
-            `simpy.Environment.run` for more details.
+            ``simpy.Environment.run`` for more details.
         """
         if until is None:
             until = self.max_run_time
@@ -110,8 +115,7 @@ class WombatEnvironment(simpy.Environment):
         super().run(until=until)
 
     def _logging_setup(self) -> None:
-        """Completes the setup for logging data.
-        """
+        """Completes the setup for logging data."""
         if self.simulation_name is None:
             simulation = "wombat"
         else:
@@ -169,10 +173,10 @@ class WombatEnvironment(simpy.Environment):
         ----------
         workday_start : int
             A valid hour in 24 hour time, by default -1. This should only be provided from an
-            `ServiceEquipmentData` object. `workday_end` must also be provided in order to be used.
+            ``ServiceEquipmentData`` object. ``workday_end`` must also be provided in order to be used.
         workday_end : int
             A valid hour in 24 hour time, by default -1. This should only be provided from an
-            `ServiceEquipmentData` object. `workday_start` must also be provided in order to be used.
+            ``ServiceEquipmentData`` object. ``workday_start`` must also be provided in order to be used.
 
         Returns
         -------
@@ -186,7 +190,7 @@ class WombatEnvironment(simpy.Environment):
     def hour_in_shift(
         self, hour: int, workday_start: int = -1, workday_end: int = -1
     ) -> bool:
-        """Checks whether an `hour` is within the working hours.
+        """Checks whether an ``hour`` is within the working hours.
 
         Parameters
         ----------
@@ -194,15 +198,15 @@ class WombatEnvironment(simpy.Environment):
             Hour of the day.
         workday_start : int
             A valid hour in 24 hour time, by default -1. This should only be provided from an
-            `ServiceEquipmentData` object. `workday_end` must also be provided in order to be used.
+            ``ServiceEquipmentData`` object. ``workday_end`` must also be provided in order to be used.
         workday_end : int
             A valid hour in 24 hour time, by default -1. This should only be provided from an
-            `ServiceEquipmentData` object. `workday_start` must also be provided in order to be used.
+            ``ServiceEquipmentData`` object. ``workday_start`` must also be provided in order to be used.
 
         Returns
         -------
         bool
-            True if `hour` is during working hours, False otherwise.
+            True if ``hour`` is during working hours, False otherwise.
         """
         if -1 in (workday_start, workday_end):
             return self.workday_start <= hour < self.workday_end
@@ -215,7 +219,7 @@ class WombatEnvironment(simpy.Environment):
         ----------
         workday_start : int
             A valid hour in 24 hour time, by default -1. This should only be provided
-            from an `ServiceEquipmentData` object.
+            from an ``ServiceEquipmentData`` object.
 
         Returns
         -------
@@ -251,7 +255,7 @@ class WombatEnvironment(simpy.Environment):
         Returns
         -------
         int
-            Index of the weather profile corresponds to the first hour of `date`.
+            Index of the weather profile corresponds to the first hour of ``date``.
         """
         return np.where(self.weather.index.date == date)[0][0]
 
@@ -270,12 +274,12 @@ class WombatEnvironment(simpy.Environment):
         ----------
         weather_file : str
             Name of the weather file to be used by the environment. Should be contained
-            within `data_dir/weather`.
+            within ``data_dir/weather``.
         start_year : Optional[int], optional
-            Custom starting year for the weather profile, by default None. If `None` or
+            Custom starting year for the weather profile, by default None. If ``None`` or
             less than the first year of the weather profile, this will be ignored.
         end_year : Optional[int], optional
-            Custom ending year for the weather profile, by default None. If `None` or
+            Custom ending year for the weather profile, by default None. If ``None`` or
             greater than the last year of the weather profile, this will be ignored.
 
         Returns
@@ -301,8 +305,7 @@ class WombatEnvironment(simpy.Environment):
         return weather
 
     def _create_endpoints(self) -> None:
-        """Creates the `start_date` and `end_date` time stamps for the simulation.
-        """
+        """Creates the ``start_date`` and ``end_date`` time stamps for the simulation."""
         self.start_datetime = self.weather.index[0].to_pydatetime()
         self.end_datetime = self.weather.index[-1].to_pydatetime()
 
@@ -317,36 +320,41 @@ class WombatEnvironment(simpy.Environment):
         """
         return self.weather.iloc[self.now].values
 
-    def weather_forecast(self, hours: int) -> np.ndarray:
-        """Returns the wind and wave data for the next `hours` hours.
+    def weather_forecast(
+        self, hours: Union[int, float]
+    ) -> Tuple[DatetimeIndex, np.ndarray, np.ndarray]:
+        """Returns the wind and wave data for the next ``hours`` hours.
 
         Parameters
         ----------
-        hours : int
-            Number of hours to look ahead.
+        hours : Union[int, float]
+            Number of hours to look ahead, rounds up to the nearest hour.
 
         Returns
         -------
-        np.ndarray
-            Array of shape `hours` x 2, representing the wind and wave data for each hour.
+        Tuple[DatetimeIndex, np.ndarray, np.ndarray]
+            The pandas DatetimeIndex, windspeed array, and waveheight array for the
+            hours requested.
         """
         start = math.ceil(self.now)
-        end = start + hours
+        end = start + math.ceil(hours)
 
-        return self.weather.iloc[start:end].values
+        weather = self.weather.iloc[start:end]
+        return (weather.index, weather.windspeed.values, weather.waveheight.values)
 
     def log_action(
         self,
-        system_id: str,
-        system_name: str,
-        part_id: str,
-        part_name: str,
-        system_ol: Union[float, str],
-        part_ol: Union[float, str],
+        *,
         agent: str,
         action: str,
         reason: str,
         additional: str = "",
+        system_id: str = "",
+        system_name: str = "",
+        part_id: str = "",
+        part_name: str = "",
+        system_ol: Union[float, str] = "",
+        part_ol: Union[float, str] = "",
         duration: float = 0,
         request_id: str = "na",
         materials_cost: Union[int, float] = 0,
@@ -358,31 +366,31 @@ class WombatEnvironment(simpy.Environment):
 
         Parameters
         ----------
-        system_id : str
-            Turbine ID, `System.id`.
-        system_name : str
-            Turbine name, `System.name`.
-        part_id : str
-            Subassembly, component, or cable ID, `_.id`.
-        part_name : str
-            Subassembly, component, or cable name, `_.name`.
-        system_ol : Union[float, str]
-            Turbine operating level, `System.operating_level`. Use an empty string for n/a.
-        part_ol : Union[float, str]
-            Subassembly, component, or cable operating level, `_.operating_level`. Use
-            an empty string for n/a.
         agent : str
             Agent performing the action.
         action : str
             Action that was taken.
-        request_id : str
-            The `RepairManager` assigned request_id found in `RepairRequest.request_id`.
         reason : str
             Reason an action was taken.
         additional : str
             Any additional information that needs to be logged.
+        system_id : str
+            Turbine ID, ``System.id``, by default "".
+        system_name : str
+            Turbine name, ``System.name``, by default "".
+        part_id : str
+            Subassembly, component, or cable ID, ``_.id``, by default "".
+        part_name : str
+            Subassembly, component, or cable name, ``_.name``, by default "".
+        system_ol : Union[float, str]
+            Turbine operating level, ``System.operating_level``. Use an empty string for n/a, by default "".
+        part_ol : Union[float, str]
+            Subassembly, component, or cable operating level, ``_.operating_level``. Use
+            an empty string for n/a, by default "".
+        request_id : str
+            The ``RepairManager`` assigned request_id found in ``RepairRequest.request_id``, by default "na".
         duration : float
-            Length of time the action lasted.
+            Length of time the action lasted, by default 0.
         materials_cost : Union[int, float], optional
             Total cost of materials for action, in USD, by default 0.
         hourly_labor_cost : Union[int, float], optional
@@ -416,8 +424,8 @@ class WombatEnvironment(simpy.Environment):
         )
 
     def _create_events_log_dataframe(self) -> pd.DataFrame:
-        """Imports the logging file created in `run` and returns it as a formatted
-        `pandas.DataFrame`.
+        """Imports the logging file created in ``run`` and returns it as a formatted
+        ``pandas.DataFrame``.
 
         Returns
         -------
@@ -465,8 +473,8 @@ class WombatEnvironment(simpy.Environment):
         return log_df
 
     def _create_operations_log_dataframe(self) -> pd.DataFrame:
-        """Imports the logging file created in `run` and returns it as a formatted
-        `pandas.DataFrame`.
+        """Imports the logging file created in ``run`` and returns it as a formatted
+        ``pandas.DataFrame``.
 
         Returns
         -------
@@ -510,8 +518,8 @@ class WombatEnvironment(simpy.Environment):
         Returns
         -------
         Tuple[pd.DataFrame, pd.DataFrame]
-            Returns nothing if `return` == False, otherwise returns the operations and
-            events log `pd.DataFrame` objects in that order.
+            Returns nothing if ``return_df`` is False, otherwise returns the operations and
+            events log ``pd.DataFrame`` objects in that order.
         """
         events = self._create_events_log_dataframe().sort_values("env_time")
         operations = self._create_operations_log_dataframe().sort_values("env_time")
@@ -534,23 +542,23 @@ class WombatEnvironment(simpy.Environment):
         windfarm: "wombat.windfarm.Windfarm",  # type: ignore
         operations: Optional[pd.DataFrame] = None,
         return_df: bool = True,
-    ) -> Union[None, Tuple[pd.DataFrame, pd.DataFrame]]:
-        """Creates the power production `DataFrame` and optionally returns it.
+    ) -> Tuple[pd.DataFrame, pd.DataFrame]:
+        """Creates the power production ``DataFrame`` and optionally returns it.
 
         Parameters
         ----------
         windfarm : wombat.windfarm.Windfarm
             The simulation's windfarm object.
         operations : Optional[pd.DataFrame], optional
-            The operations log `DataFrame` if readily available, by default None. If
-            `None`, then it will be created through `convert_logs_to_csv()`.
+            The operations log ``DataFrame`` if readily available, by default None. If
+            ``None``, then it will be created through ``convert_logs_to_csv()``.
         return_df : bool, optional
             Indicator to return the power production for further usage, by default True.
 
         Returns
         -------
-        Union[None, pd.DataFrame]
-            The power production timeseries data.
+        Tuple[pd.DataFrame, pd.DataFrame]
+            The power potential and production timeseries data.
         """
         if operations is None:
             operations = self._create_operations_log_dataframe().sort_values("env_time")
