@@ -1,16 +1,16 @@
 """The postprocessing metric computation."""
 
 import os  # type: ignore
-from copy import deepcopy  # type: ignore
-from functools import partial  # type: ignore
-from itertools import product  # type: ignore
-from pathlib import Path  # type: ignore
-from typing import List, Tuple, Union  # type: ignore
-
 import numpy as np  # type: ignore
+import PySAM
 import pandas as pd  # type: ignore
 import PySAM.PySSC as pssc  # type: ignore
 import PySAM.Singleowner as pysam_singleowner_financial_model  # type: ignore
+from copy import deepcopy  # type: ignore
+from typing import List, Tuple, Union  # type: ignore
+from pathlib import Path  # type: ignore
+from functools import partial  # type: ignore
+from itertools import product  # type: ignore
 
 from wombat.core import FixedCosts
 from wombat.core.library import load_yaml
@@ -42,19 +42,19 @@ def _calculate_time_availability(
 def _process_single(
     events: pd.DataFrame, request_filter: np.ndarray
 ) -> Tuple[str, float, float, float, int]:
-    """Computes the timing values for a single `request_id`.
+    """Computes the timing values for a single ``request_id``.
 
     Parameters
     ----------
     events : pd.DataFrame
-        The NaN-filtered events `pd.DataFrame`.
+        The NaN-filtered events ``pd.DataFrame``.
     request_filter : np.ndarray
         The indicies to include for the calculation of the timings.
 
     Returns
     -------
     Tuple[str, float, float, float, int]
-        The timing values. See `process_times`.
+        The timing values. See ``process_times``.
     """
     request = events.iloc[request_filter]
     downtime = request[request.system_operating_level < 1]
@@ -70,8 +70,7 @@ def _process_single(
 
 
 class Metrics:
-    """The metric computation class that will store the logged outputs and compile results.
-    """
+    """The metric computation class that will store the logged outputs and compile results."""
 
     _hourly_cost = "hourly_labor_cost"
     _salary_cost = "salary_labor_cost"
@@ -102,7 +101,7 @@ class Metrics:
         substation_id: Union[str, List[str]],
         turbine_id: Union[str, List[str]],
         service_equipment_names: Union[str, List[str]],
-        SAM_settings: str = "SAM_Singleowner_defaults.yaml",
+        SAM_settings: Union[str, None] = None,
     ) -> None:
         """Initializes the Metrics class.
 
@@ -111,14 +110,14 @@ class Metrics:
         data_dir : Union[str, Path]
             This should be the same as was used for running the analysis.
         events : Union[str, pd.DataFrame]
-            Either a pandas `DataFrame` or filename to be used to read the csv log data.
+            Either a pandas ``DataFrame`` or filename to be used to read the csv log data.
         operations : Union[str, pd.DataFrame]
-            Either a pandas `DataFrame` or filename to be used to read the csv log data.
+            Either a pandas ``DataFrame`` or filename to be used to read the csv log data.
         potential : Union[str, pd.DataFrame]
-            Either a pandas `DataFrame` or a filename to be used to read the csv
+            Either a pandas ``DataFrame`` or a filename to be used to read the csv
             potential power production data.
         production : Union[str, pd.DataFrame]
-            Either a pandas `DataFrame` or a filename to be used to read the csv power
+            Either a pandas ``DataFrame`` or a filename to be used to read the csv power
             production data.
         inflation_rate : float
             The inflation rate to be applied to all dollar amounts from the analysis
@@ -126,7 +125,7 @@ class Metrics:
         project_capacity : float
             The project's rated capacity, in MW.
         turbine_capacities : Union[float, List[float]]
-            The capacity of each individual turbine corresponding to `turbine_id`, in kW.
+            The capacity of each individual turbine corresponding to ``turbine_id``, in kW.
         fixed_costs : str
             The filename of the project's fixed costs.
         substation_id : Union[str, List[str]]
@@ -135,11 +134,13 @@ class Metrics:
             The turbine id(s).
         service_equipment_names : Union[str, List[str]]
             The names of the servicing equipment, corresponding to
-            `ServiceEquipment.settings.name` for each `ServiceEquipment` in the
+            ``ServiceEquipment.settings.name`` for each ``ServiceEquipment`` in the
             simulation.
-        SAM_settings : str
-            The SAM settings YAML file located in <data_dir>/windfarm/<SAM_settings> that
-            should end in ".yaml", by default "SAM_Singleowner_defaults.yaml".
+        SAM_settings : Union[str, None]
+            The SAM settings YAML file located in <data_dir>/windfarm/<SAM_settings>
+            that should end in ".yaml". If no input is provided, then the model will
+            raise a ``NotImplementedError`` when the SAM-powered metrics are attempted to
+            be accessed.
         """
         self.data_dir = Path(data_dir)
         if not os.path.isdir(self.data_dir):
@@ -151,10 +152,6 @@ class Metrics:
         fixed_costs = load_yaml(self.data_dir / "windfarm", fixed_costs)
         self.fixed_costs = FixedCosts(**fixed_costs)  # type: ignore
 
-        if SAM_settings is None:
-            SAM_settings = "SAM_Singleowner_defaults.yaml"
-        self.sam_settings = load_yaml(self.data_dir / "windfarm", SAM_settings)
-
         if isinstance(substation_id, str):
             substation_id = [substation_id]
         self.substation_id = substation_id
@@ -187,10 +184,16 @@ class Metrics:
             production = self._read_data(production)
         self.production = self._tidy_data(production, kind="production")
 
-        self._setup_pysam()
+        if SAM_settings is not None:
+            SAM_settings = "SAM_Singleowner_defaults.yaml"
+            self.sam_settings = load_yaml(self.data_dir / "windfarm", SAM_settings)
+            self._setup_pysam()
+        else:
+            self.sam_settings = None
+            self.financial_model = None
 
     def _tidy_data(self, data: pd.DataFrame, kind: str) -> pd.DataFrame:
-        """Tidies the "raw" csv-converted data to be able to be used among the `Metrics`
+        """Tidies the "raw" csv-converted data to be able to be used among the ``Metrics``
         class.
 
         Parameters
@@ -198,7 +201,7 @@ class Metrics:
         data : pd.DataFrame
             The freshly imported csv log data.
         kind : str
-            The category of the input provided to `data`. Should be one of:
+            The category of the input provided to ``data``. Should be one of:
              - "operations"
              - "events"
              - "potential"
@@ -274,8 +277,7 @@ class Metrics:
         return events
 
     def _setup_pysam(self) -> None:
-        """Creates and executes the PySAM model for financial metrics.
-        """
+        """Creates and executes the PySAM model for financial metrics."""
         # Define the model and import the SAM settings file.
         self.financial_model = pysam_singleowner_financial_model.default(
             "WindPowerSingleOwner"
@@ -291,6 +293,9 @@ class Metrics:
         # Create a years variable for later use with the PySAM outputs
         self.years = sorted(self.production.year.unique())
 
+        # Let mypy know that I know what I'm doing
+        assert isinstance(self.financial_model, PySAM.Singleowner.Singleowner)
+
         # Replace the coded generation with modeled generation
         self.financial_model.FinancialParameters.analysis_period = len(self.years)
         self.financial_model.SystemOutput.gen = generation
@@ -310,7 +315,7 @@ class Metrics:
         value, annual average, or monthly average for the whole windfarm or by turbine.
 
         .. note:: This currently assumes that if there are multiple substations, that
-        the turbines are all connected to multiple.
+          the turbines are all connected to multiple.
 
         Parameters
         ----------
@@ -327,12 +332,12 @@ class Metrics:
         frequency = frequency.lower().strip()
         if frequency not in ("project", "annual", "monthly", "month-year"):
             raise ValueError(
-                '`frequency` must be one of "project", "annual", "monthly", or "month-year".'
+                '``frequency`` must be one of "project", "annual", "monthly", or "month-year".'
             )
 
         by = by.lower().strip()
         if by not in ("windfarm", "turbine"):
-            raise ValueError('`by` must be one of "windfarm" or "turbine".')
+            raise ValueError('``by`` must be one of "windfarm" or "turbine".')
         by_turbine = by == "turbine"
 
         operations = deepcopy(self.operations)
@@ -398,7 +403,7 @@ class Metrics:
         turbine.
 
         .. note:: This currently assumes that if there are multiple substations, that
-        the turbines are all connected to multiple.
+          the turbines are all connected to multiple.
 
         Parameters
         ----------
@@ -415,12 +420,12 @@ class Metrics:
         frequency = frequency.lower().strip()
         if frequency not in ("project", "annual", "monthly", "month-year"):
             raise ValueError(
-                '`frequency` must be one of "project", "annual", "monthly", or "month-year".'
+                '``frequency`` must be one of "project", "annual", "monthly", or "month-year".'
             )
 
         by = by.lower().strip()
         if by not in ("windfarm", "turbine"):
-            raise ValueError('`by` must be one of "windfarm" or "turbine".')
+            raise ValueError('``by`` must be one of "windfarm" or "turbine".')
         by_turbine = by == "turbine"
 
         production = self.production.loc[:, self.turbine_id]
@@ -476,7 +481,7 @@ class Metrics:
         annual average, or monthly average for the whole windfarm or by turbine.
 
         .. note:: This currently assumes that if there are multiple substations, that
-        the turbines are all connected to multiple.
+          the turbines are all connected to multiple.
 
 
         Parameters
@@ -495,17 +500,17 @@ class Metrics:
         """
         which = which.lower().strip()
         if which not in ("net", "gross"):
-            raise ValueError('`which` must be one of "net" or "gross".')
+            raise ValueError('``which`` must be one of "net" or "gross".')
 
         frequency = frequency.lower().strip()
         if frequency not in ("project", "annual", "monthly", "month-year"):
             raise ValueError(
-                '`frequency` must be one of "project", "annual", "monthly", or "month-year".'
+                '``frequency`` must be one of "project", "annual", "monthly", or "month-year".'
             )
 
         by = by.lower().strip()
         if by not in ("windfarm", "turbine"):
-            raise ValueError('`by` must be one of "windfarm" or "turbine".')
+            raise ValueError('``by`` must be one of "windfarm" or "turbine".')
         by_turbine = by == "turbine"
         capacity = (
             np.array(self.turbine_capacities) if by_turbine else self.project_capacity
@@ -558,7 +563,7 @@ class Metrics:
         annual average, or monthly average for the whole windfarm or by turbine.
 
         .. note:: This currently assumes that if there are multiple substations, that
-        the turbines are all connected to multiple.
+          the turbines are all connected to multiple.
 
         Parameters
         ----------
@@ -575,13 +580,13 @@ class Metrics:
         which = which.lower().strip()
         if which not in ("scheduled", "unscheduled", "both"):
             raise ValueError(
-                '`which` must be one of "scheduled", "unscheduled", or "both".'
+                '``which`` must be one of "scheduled", "unscheduled", or "both".'
             )
 
         frequency = frequency.lower().strip()
         if frequency not in ("project", "annual", "monthly", "month-year"):
             raise ValueError(
-                '`frequency` must be one of "project", "annual", "monthly", or "month-year".'
+                '``frequency`` must be one of "project", "annual", "monthly", or "month-year".'
             )
 
         if which == "scheduled":
@@ -602,7 +607,7 @@ class Metrics:
         ].reset_index(drop=True)
 
         if frequency == "project":
-            return requests.shape[0] / completions.shape[0]
+            return completions.shape[0] / requests.shape[0]
 
         requests[["year", "month"]] = [
             requests.env_datetime.dt.year.values.reshape(-1, 1),
@@ -666,7 +671,7 @@ class Metrics:
         Returns
         -------
         Union[float, pd.DataFrame]
-            Returns either a float for whole project-level costs or a pandas `DataFrame`
+            Returns either a float for whole project-level costs or a pandas ``DataFrame``
             with columns:
                 - year (if appropriate for frequency)
                 - month (if appropriate for frequency)
@@ -675,18 +680,18 @@ class Metrics:
         Raises
         ------
         ValueError
-            If `frequency` is not one of "project", "annual", "monthly", or "month-year".
+            If ``frequency`` is not one of "project", "annual", "monthly", or "month-year".
         ValueError
-            If `by_equipment` is not one of `True` or `False`.
+            If ``by_equipment`` is not one of ``True`` or ``False``.
         """
         frequency = frequency.lower().strip()
         if frequency not in ("project", "annual", "monthly", "month-year"):
             raise ValueError(
-                '`frequency` must be one of "project", "annual", or "monthly".'
+                '``frequency`` must be one of "project", "annual", or "monthly".'
             )
 
         if not isinstance(by_equipment, bool):
-            raise ValueError("`by_equipment` must be one of `True` or `False`")
+            raise ValueError("``by_equipment`` must be one of ``True`` or ``False``")
 
         if frequency == "annual":
             col_filter = ["year"]
@@ -748,16 +753,16 @@ class Metrics:
         Returns
         -------
         pd.DataFrame
-            The utilization rate of each of the simulation `SerivceEquipment`.
+            The utilization rate of each of the simulation ``SerivceEquipment``.
 
         Raises
         ------
         ValueError
-            If `frequency` is not one of "project" or "annual".
+            If ``frequency`` is not one of "project" or "annual".
         """
         frequency = frequency.lower().strip()
         if frequency not in ("project", "annual"):
-            raise ValueError('`frequency` must be one of "project" or "annual".')
+            raise ValueError('``frequency`` must be one of "project" or "annual".')
 
         no_requests = []
         total_days = []
@@ -824,7 +829,7 @@ class Metrics:
         Returns
         -------
         Union[float, pd.DataFrame]
-            Returns either a float for whole project-level costs or a pandas `DataFrame`
+            Returns either a float for whole project-level costs or a pandas ``DataFrame``
             with columns:
 
              - year (if appropriate for frequency)
@@ -836,18 +841,18 @@ class Metrics:
         Raises
         ------
         ValueError
-            If `frequency` is not one of "project", "annual", "monthly", or "month-year".
+            If ``frequency`` is not one of "project", "annual", "monthly", or "month-year".
         ValueError
-            If `by_type` is not one of `True` or `False`.
+            If ``by_type`` is not one of ``True`` or ``False``.
         """
         frequency = frequency.lower().strip()
         if frequency not in ("project", "annual", "monthly", "month-year"):
             raise ValueError(
-                '`frequency` must be one of "project", "annual", "monthly", or "month-year".'
+                '``frequency`` must be one of "project", "annual", "monthly", or "month-year".'
             )
 
         if not isinstance(by_type, bool):
-            raise ValueError("`by_equipment` must be one of `True` or `False`")
+            raise ValueError("``by_equipment`` must be one of ``True`` or ``False``")
 
         labor_cols = [self._hourly_cost, self._salary_cost, self._labor_cost]
         if frequency == "project":
@@ -895,30 +900,30 @@ class Metrics:
         Returns
         -------
         pd.DataFrame
-            Returns pandas `DataFrame` with columns:
+            Returns pandas ``DataFrame`` with columns:
                 - year (if appropriate for frequency)
                 - month (if appropriate for frequency)
                 - reason
-                - hourly_labor_cost (if by_category == `True`)
-                - salary_labor_cost (if by_category == `True`)
-                - total_labor_cost (if by_category == `True`)
-                - equipment_cost (if by_category == `True`)
+                - hourly_labor_cost (if by_category == ``True``)
+                - salary_labor_cost (if by_category == ``True``)
+                - total_labor_cost (if by_category == ``True``)
+                - equipment_cost (if by_category == ``True``)
                 - total_cost (if broken out)
 
         Raises
         ------
         ValueError
-            If `frequency` is not one of "project", "annual", "monthly", or "month-year".
+            If ``frequency`` is not one of "project", "annual", "monthly", or "month-year".
         ValueError
-            If `by_category` is not one of `True` or `False`.
+            If ``by_category`` is not one of ``True`` or ``False``.
         """
         frequency = frequency.lower().strip()
         if frequency not in ("project", "annual", "monthly", "month-year"):
             raise ValueError(
-                '`frequency` must be one of "project", "annual", or "monthly".'
+                '``frequency`` must be one of "project", "annual", or "monthly".'
             )
         if not isinstance(by_category, bool):
-            raise ValueError("`by_equipment` must be one of `True` or `False`")
+            raise ValueError("``by_equipment`` must be one of ``True`` or ``False``")
 
         group_filter = ["action", "reason", "additional"]
         if frequency in ("annual", "month-year"):
@@ -1044,6 +1049,7 @@ class Metrics:
             weather delays and shift-to-shift delays. In the future these will be
             disentangled.
 
+
         Parameters
         ----------
         frequency : str
@@ -1059,7 +1065,7 @@ class Metrics:
         Returns
         -------
         Union[float, pd.DataFrame]
-            Returns either a float for whole project-level costs or a pandas `DataFrame`
+            Returns either a float for whole project-level costs or a pandas ``DataFrame``
             with columns:
                 - year (if appropriate for frequency)
                 - month (if appropriate for frequency)
@@ -1073,21 +1079,21 @@ class Metrics:
         Raises
         ------
         ValueError
-            If `frequency` is not one of "project", "annual", "monthly", or "month-year".
+            If ``frequency`` is not one of "project", "annual", "monthly", or "month-year".
         ValueError
-            If `by_category` is not one of `True` or `False`.
+            If ``by_category`` is not one of ``True`` or ``False``.
         ValueError
-            If `by_action` is not one of `True` or `False`.
+            If ``by_action`` is not one of ``True`` or ``False``.
         """
         frequency = frequency.lower().strip()
         if frequency not in ("project", "annual", "monthly", "month-year"):
             raise ValueError(
-                '`frequency` must be one of "project", "annual", or "monthly".'
+                '``frequency`` must be one of "project", "annual", or "monthly".'
             )
         if not isinstance(by_category, bool):
-            raise ValueError("`by_equipment` must be one of `True` or `False`")
+            raise ValueError("``by_equipment`` must be one of ``True`` or ``False``")
         if not isinstance(by_action, bool):
-            raise ValueError("`by_equipment` must be one of `True` or `False`")
+            raise ValueError("``by_equipment`` must be one of ``True`` or ``False``")
 
         events = deepcopy(self.events)
         events = events[~events.part_id.isna()]
@@ -1195,11 +1201,12 @@ class Metrics:
         resolution : str
             One of "low", "medium", or "high", where the values correspond to:
 
-             - low: `FixedCosts.resolution["low"]`, corresponding to the itemized costs.
-             - medium: `FixedCosts.resolution["medium"]`, corresponding to the
-             overarching cost categories.
-             - high: `FixedCosts.resolution["high"]`, corresponding to a lump sum.
-            These values can also be seen through the `FixedCosts.hierarchy`
+             - low: ``FixedCosts.resolution["low"]``, corresponding to the itemized costs.
+             - medium: ``FixedCosts.resolution["medium"]``, corresponding to the
+               overarching cost categories.
+             - high: ``FixedCosts.resolution["high"]``, corresponding to a lump sum.
+
+            These values can also be seen through the ``FixedCosts.hierarchy``
 
         Returns
         -------
@@ -1210,17 +1217,19 @@ class Metrics:
         Raises
         ------
         ValueError
-            If `frequency` not one of "project" or "annual".
+            If ``frequency`` not one of "project" or "annual".
         ValueError
-            If `resolution` must be one of "low", "medium", or "high".
+            If ``resolution`` must be one of "low", "medium", or "high".
         """
         frequency = frequency.lower().strip()
         if frequency not in ("project", "annual"):
-            raise ValueError('`frequency` must be one of "project" or "annual".')
+            raise ValueError('``frequency`` must be one of "project" or "annual".')
 
         resolution = resolution.lower().strip()
         if resolution not in ("low", "medium", "high"):
-            raise ValueError('`resolution` must be one of "low", "medium", or "high".')
+            raise ValueError(
+                '``resolution`` must be one of "low", "medium", or "high".'
+            )
 
         keys = self.fixed_costs.resolution[resolution]
         vals = [[getattr(self.fixed_costs, key) for key in keys]]
@@ -1292,7 +1301,7 @@ class Metrics:
         Returns
         -------
         Union[float, pd.DataFrame]
-            Returns either a float for whole project-level costs or a pandas `DataFrame`
+            Returns either a float for whole project-level costs or a pandas ``DataFrame``
             with columns:
 
              - year (if appropriate for frequency)
@@ -1303,18 +1312,18 @@ class Metrics:
         Raises
         ------
         ValueError
-            If `frequency` is not one of "project", "annual", "monthly", or "month-year".
+            If ``frequency`` is not one of "project", "annual", "monthly", or "month-year".
         ValueError
-            If `by_turbine` is not one of `True` or `False`.
+            If ``by_turbine`` is not one of ``True`` or ``False``.
         """
         frequency = frequency.lower().strip()
         if frequency not in ("project", "annual", "monthly", "month-year"):
             raise ValueError(
-                '`frequency` must be one of "project", "annual", or "monthly".'
+                '``frequency`` must be one of "project", "annual", or "monthly".'
             )
 
         if not isinstance(by_turbine, bool):
-            raise ValueError("`by_turbine` must be one of `True` or `False`")
+            raise ValueError("``by_turbine`` must be one of ``True`` or ``False``")
 
         if frequency == "annual":
             group_cols = ["year"]
@@ -1344,11 +1353,19 @@ class Metrics:
 
         See here for more: https://nrel-pysam.readthedocs.io/en/master/modules/Singleowner.html#PySAM.Singleowner.Singleowner.Outputs.cf_project_return_aftertax_npv
 
+        Raises
+        ------
+        NotImplementedError: Raised if a PySAM input file is not provided to run the model.
+
         Returns
         -------
         float
             Final, project-level NPV, in $.
         """
+        if self.financial_model is None:
+            raise NotImplementedError(
+                "No SAM inputs were provided, and 'pysam_npv()' cannot be calculated!"
+            )
         npv = self.financial_model.Outputs.cf_project_return_aftertax_npv
         npv = npv[len(self.years)]
         return npv
@@ -1358,11 +1375,19 @@ class Metrics:
 
         See here for more: https://nrel-pysam.readthedocs.io/en/master/modules/Singleowner.html#PySAM.Singleowner.Singleowner.Outputs.lcoe_real
 
+        Raises
+        ------
+        NotImplementedError: Raised if a PySAM input file is not provided to run the model.
+
         Returns
         -------
         float
             Real LCOE, in $/kW.
         """
+        if self.financial_model is None:
+            raise NotImplementedError(
+                "No SAM inputs were provided, and 'pysam_lcoe_real()' cannot be calculated!"
+            )
         return self.financial_model.Outputs.lcoe_real / 100.0
 
     def pysam_lcoe_nominal(self) -> float:
@@ -1370,11 +1395,19 @@ class Metrics:
 
         See here for more: https://nrel-pysam.readthedocs.io/en/master/modules/Singleowner.html#PySAM.Singleowner.Singleowner.Outputs.lcoe_nom
 
+        Raises
+        ------
+        NotImplementedError: Raised if a PySAM input file is not provided to run the model.
+
         Returns
         -------
         float
             Nominal LCOE, in $/kW.
         """
+        if self.financial_model is None:
+            raise NotImplementedError(
+                "No SAM inputs were provided, and 'pysam_lcoe_nominal()' cannot be calculated!"
+            )
         return self.financial_model.Outputs.lcoe_nom / 100.0
 
     def pysam_irr(self) -> float:
@@ -1382,11 +1415,19 @@ class Metrics:
 
         See here for more: https://nrel-pysam.readthedocs.io/en/master/modules/Singleowner.html#PySAM.Singleowner.Singleowner.Outputs.cf_project_return_aftertax_irr
 
+        Raises
+        ------
+        NotImplementedError: Raised if a PySAM input file is not provided to run the model.
+
         Returns
         -------
         pd.DataFrame
             Annual after-tax IRR value, in %.
         """
+        if self.financial_model is None:
+            raise NotImplementedError(
+                "No SAM inputs were provided, and 'pysam_irr()' cannot be calculated!"
+            )
         irr = self.financial_model.Outputs.cf_project_return_aftertax_irr
         irr = irr[len(self.years)]
         return irr
@@ -1400,11 +1441,19 @@ class Metrics:
          - Real LOCE
          - IRR
 
+        Raises
+        ------
+        NotImplementedError: Raised if a PySAM input file is not provided to run the model.
+
         Returns
         -------
         pd.DataFrame
             Project financial values values.
         """
+        if self.financial_model is None:
+            raise NotImplementedError(
+                "No SAM inputs were provided, and 'pysam_all_outputs()' cannot be calculated!"
+            )
         financials = [
             self.pysam_npv(),
             self.pysam_lcoe_nominal(),
